@@ -10,6 +10,7 @@ version_to_name = {
     (6, 1): 'Windows Server 2008 R2',
     (6, 2, 1): 'Windows 8',
     (6, 2): 'Windows Server 2012',
+    (6, 3): 'Windows Server 2012 R2',
 }
 name_to_version = {value: key[:2] for key, value in version_to_name.items()}
 
@@ -145,6 +146,9 @@ class Windows(object): #pylint: disable-msg=R0902,R0904
     def is_windows_2012(self):
         return self.version == 'Windows Server 2012'
 
+    def is_windows_2012_r2(self):
+        return self.version == 'Windows Server 2012 R2'
+
     def is_x86(self):
         return self.architecture == 'x86'
 
